import React from 'react'
import './App.css'
import { Switch, Route, Redirect } from 'react-router-dom'
import { useSelector } from 'react-redux'
import { ThemeProvider, createMuiTheme, useMediaQuery } from '@material-ui/core'
import { purple, teal } from '@material-ui/core/colors'

import Login from './Components/Login'
import Dashboard from './Components/Dashboard'

function App() {
	const logged = useSelector(state => state.login.logged)

	const prefersDarkMode = useMediaQuery('(prefers-color-scheme: dark)');


	const theme = createMuiTheme({
		palette: {
			type: prefersDarkMode? 'dark' : 'light',
			primary: { main: prefersDarkMode? teal[300] : '#009688' },
			secondary: { main: prefersDarkMode? purple[300] : purple[700] },
			background: { 
				default: prefersDarkMode? '#121212' : '#fafafa',
				level1: prefersDarkMode? '#212121' : '#fff',
				level2: prefersDarkMode? '#212121' : '#f5f5f5',
				paper: prefersDarkMode? '#424242' : '#fff'
			}
		}
	})
	return (
		<ThemeProvider theme={theme}>
			<Switch>
				<Route exact path='/'>
					<Login />
				</Route>
				{logged ? (
					<Route path='/dashboard'>
						<Dashboard />
					</Route>
				) : (
					<Redirect to='/' />
				)}
			</Switch>
		</ThemeProvider>
	)
}

export default App
